gdrive_client_setup.Rd
reads values from the enviroment for configurating a google drive client for accesing gdrive file or gsheets data
gdrive_client_setup()
'client' for use in drive_auth_configure or