convert a type name to a readr convert code
type_code_to_readr_code.Rdreadr uses convert codes - see vignette("readr") this function allows for named types and will convert those to the 1-letter codes used by reader
type_code_to_readr_code.Rdreadr uses convert codes - see vignette("readr") this function allows for named types and will convert those to the 1-letter codes used by reader