get_drive_email.Rd
convenience method for replacing an empty drive, called by drive_setup
get_drive_email(drive_email = NULL)
optional str, email address, if not provided will use envronment
string, the email to use, either what was sent or from the config