given a URL and params, read, validate and save a CSV
read_validate_and_save.Rdin the schemed used by this system, there is an ID column which is the ID value of the unit of research (usually a publication, but could be a project, a system) which is repeated for each row in order to positively ID the row of data to that unit. The sheet may be also named that but the sheet name is not used for this ID value.